@@ -31,11 +31,12 @@
 static KAboutData about(
     APP_NAME,
     0,
-    ki18n("Filelight"),
+    ki18n(APP_PRETTYNAME),
     APP_VERSION,
     ki18n("Graphical disk-usage information"),
-    KAboutData::License_GPL_V3,
-    ki18n("(C) 2006 Max Howell\n(C) 2008, 2009 Martin Sandsmark"),
+    KAboutData::License_GPL,
+    ki18n("(C) 2006 Max Howell\n\
+        (C) 2008-2013 Martin Sandsmark"),
     KLocalizedString(),
     "http://utils.kde.org/projects/filelight");
 
@@ -49,11 +50,13 @@ int main(int argc, char *argv[])
     about.addCredit(ki18n("Lukas Appelhans"),  ki18n("Help and support"));
     about.addCredit(ki18n("Steffen Gerlach"),  ki18n("Inspiration"), 0, "http://www.steffengerlach.de/");
     about.addCredit(ki18n("Mike Diehl"),       ki18n("Original documentation"), 0, 0);
+    about.addCredit(ki18n("Sune Vuorela"),     ki18n("Icon"), 0, 0);
+    about.addCredit(ki18n("Nuno Pinheiro"),    ki18n("Icon"), 0, 0);
 
     KCmdLineArgs::init(argc, argv, &about);
 
     KCmdLineOptions options;
-    KLocale *tmpLocale = new KLocale(QLatin1String("filelight"));
+    KLocale *tmpLocale = new KLocale(QLatin1String(APP_NAME));
     options.add(ki18nc("Path in the file system to scan", "+[path]").toString(tmpLocale).toLocal8Bit(), ki18n("Scan 'path'"));
     delete tmpLocale;
     KCmdLineArgs::addCmdLineOptions(options);
